#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-CzKxMS221MH7p8VeDa3GLG
key:                  lambdabot-trusted-5.3.1.2-CzKxMS221MH7p8VeDa3GLG
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  27cdd8bd8ac12bbfe3eb531d76791fb1
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-CzKxMS221MH7p8VeDa3GLG
depends:
    QuickCheck-2.15.0.1-JVa2LJ8cbiDGUmMXnglivi
    QuickCheck-safe-0.1.0.6-4yNm1wm7Ai4DAjTf3Opwxr base-4.18.2.1
    oeis-0.3.10.2-DfWcWSB0xmEKSJz1wLMH0t

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

